aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorkpfleming <kpfleming@f38db490-d61c-443f-a65b-d21fe96a405b>2005-08-25 23:23:26 +0000
committerkpfleming <kpfleming@f38db490-d61c-443f-a65b-d21fe96a405b>2005-08-25 23:23:26 +0000
commitd02a0e57996edeecc7f2e7782884e1adea9dbcb8 (patch)
tree9918a2a495885b959c7c7584e7fa3e41164954cc /include
parentb7a008677cea9ca1f0ea940b043cc4ddd3f12c43 (diff)
doc updates and copyright header cleanup (issue #5026)
git-svn-id: http://svn.digium.com/svn/asterisk/trunk@6411 f38db490-d61c-443f-a65b-d21fe96a405b
Diffstat (limited to 'include')
-rwxr-xr-xinclude/asterisk/srv.h26
1 files changed, 22 insertions, 4 deletions
diff --git a/include/asterisk/srv.h b/include/asterisk/srv.h
index 1c3711dae..5afb1b469 100755
--- a/include/asterisk/srv.h
+++ b/include/asterisk/srv.h
@@ -1,14 +1,16 @@
/*
* Asterisk -- A telephony toolkit for Linux.
*
- * ENUM support
+ * DNS SRV record support
*
- * Copyright (C) 1999, Mark Spencer
+ * Copyright (C) 1999-2005, Digium, Inc.
*
- * Mark Spencer <markster@linux-support.net>
+ * Mark Spencer <markster@digium.com>
*
* This program is free software, distributed under the terms of
* the GNU General Public License
+ *
+ * $Revision$
*/
#ifndef _ASTERISK_SRV_H
@@ -16,7 +18,23 @@
struct ast_channel;
-/* Lookup entry in SRV records Returns 1 if found, 0 if not found, -1 on hangup */
+/*!
+ \file srv.h
+ \brief Support for DNS SRV records, used in to locate SIP services.
+ Note: The Asterisk DNS SRV record support is broken, it only
+ supports the first DNS SRV record and will give no load
+ balancing or failover support.
+*/
+
+/*! Lookup entry in SRV records Returns 1 if found, 0 if not found, -1 on hangup
+ Only do SRV record lookup if you get a domain without a port. If you get a port #, it's a DNS host name.
+*/
+/*! \param chan Ast channel
+ \param host host name (return value)
+ \param hostlen Length of string "host"
+ \param port Port number (return value)
+ \param service Service tag for SRV lookup (like "_sip._udp" or "_stun._udp"
+*/
extern int ast_get_srv(struct ast_channel *chan, char *host, int hostlen, int *port, const char *service);
#endif